summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorAndrew Jeffery <andrew@aj.id.au>2018-08-08 17:21:34 +0930
committerAndrew Jeffery <andrew@aj.id.au>2018-09-05 17:44:24 +0930
commit5dc9f9597c012c2611dbdf0ea6d729e98f2d92ce (patch)
tree4d7aff9e17bee53476f1560c11dc678fec49fdb9
parentb65bb4c509703e264ba630c3e20f5b28a83b65a8 (diff)
downloadphosphor-mboxbridge-5dc9f9597c012c2611dbdf0ea6d729e98f2d92ce.tar.gz
phosphor-mboxbridge-5dc9f9597c012c2611dbdf0ea6d729e98f2d92ce.zip
windows: Rename reset_window to window_reset
Change-Id: I68a9e19c229b4c786be2a00c3ca7ed5e274c7a0f Signed-off-by: Andrew Jeffery <andrew@aj.id.au>
-rw-r--r--windows.c12
-rw-r--r--windows.h2
2 files changed, 7 insertions, 7 deletions
diff --git a/windows.h b/windows.h
index 54147fb..30ed68f 100644
--- a/windows.h
+++ b/windows.h
@@ -23,7 +23,7 @@ int window_set_bytemap(struct mbox_context *context, struct window_context *cur,
uint32_t offset, uint32_t size, uint8_t val);
void windows_close_current(struct mbox_context *context, bool set_bmc_event,
uint8_t flags);
-void reset_window(struct mbox_context *context, struct window_context *window);
+void window_reset(struct mbox_context *context, struct window_context *window);
void reset_all_windows(struct mbox_context *context, bool set_bmc_event);
struct window_context *find_oldest_window(struct mbox_context *context);
struct window_context *find_largest_window(struct mbox_context *context);
OpenPOWER on IntegriCloud
diff --git a/windows.c b/windows.c
index 2ec8b9a..729a4d3 100644
--- a/windows.c
+++ b/windows.c
@@ -406,11 +406,11 @@ void windows_close_current(struct mbox_context *context, bool set_bmc_event,
}
/*
* reset_window() - Reset a window context to a well defined default state
* @context: The mbox context pointer
* @window: The window to reset
*/
-void reset_window(struct mbox_context *context, struct window_context *window)
+void window_reset(struct mbox_context *context, struct window_context *window)
{
window->flash_offset = FLASH_OFFSET_UNINIT;
window->size = context->windows.default_size;
@@ -437,7 +437,7 @@ void reset_all_windows(struct mbox_context *context, bool set_bmc_event)
windows_close_current(context, set_bmc_event, FLAGS_NONE);
}
for (i = 0; i < context->windows.num; i++) {
- reset_window(context, &context->windows.window[i]);
+ window_reset(context, &context->windows.window[i]);
}
context->windows.max_age = 0;
@@ -568,7 +568,7 @@ int create_map_window(struct mbox_context *context,
if (!cur) {
MSG_DBG("No uninitialised window, evicting one\n");
cur = find_oldest_window(context);
- reset_window(context, cur);
+ window_reset(context, cur);
}
/*
@@ -622,7 +622,7 @@ int create_map_window(struct mbox_context *context,
rc = flash_copy(context, offset, cur->mem, cur->size);
if (rc < 0) {
/* We don't know how much we've copied -> better reset window */
- reset_window(context, cur);
+ window_reset(context, cur);
return rc;
}
/*
@@ -653,7 +653,7 @@ int create_map_window(struct mbox_context *context,
do {
tmp = search_windows(context, i, false);
if (tmp) {
- reset_window(context, tmp);
+ window_reset(context, tmp);
}
} while (tmp);
}
@@ -406,11 +406,11 @@ void windows_close_current(struct mbox_context *context, bool set_bmc_event,
}
/*
- * reset_window() - Reset a window context to a well defined default state
+ * window_reset() - Reset a window context to a well defined default state
* @context: The mbox context pointer
* @window: The window to reset